@@ -3,5 +3,5 @@ use std::{fs, io};
 
 #[inline]
 pub(crate) fn is_file_read_write_impl(file: &fs::File) -> io::Result<(bool, bool)> {
-    is_file_read_write(file)
+    Ok(is_file_read_write(file)?)
 }
