@@ -5,7 +5,6 @@
 use super::file_metadata;
 use crate::fs::{manually, open_beneath, FollowSymlinks, Metadata, OpenOptions};
 use posish::fs::OFlags;
-use posish::io::Errno;
 use std::{fs, io, path::Path};
 
 /// Use `openat2` with `O_PATH` and `fstat`. If that's not available, fallback
@@ -32,10 +31,10 @@ pub(crate) fn stat_impl(
     // If that worked, call `fstat`.
     match result {
         Ok(file) => file_metadata(&file),
-        Err(err) => match Errno::from_io_error(&err) {
+        Err(err) => match posish::io::Error::from_io_error(&err) {
             // `ENOSYS` from `open_beneath` means `openat2` is unavailable
             // and we should use a fallback.
-            Some(Errno::NOSYS) => manually::stat(start, path, follow),
+            Some(posish::io::Error::NOSYS) => manually::stat(start, path, follow),
             _ => Err(err),
         },
     }
